"use strict";
// FYI
// packages/@guardian/src-foundations/src/size.ts SYMLINKS TO
// packages/@guardian/source-foundations/src/size/size.ts
Object.defineProperty(exports, "__esModule", { value: true });
exports.remWidth = exports.width = exports.remHeight = exports.height = exports.iconSize = exports.size = void 0;
const px_to_rem_1 = require("./utils/px-to-rem");
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#global-size-values) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * May be used for call to action buttons and user input fields.
 */
exports.size = {
    xsmall: 24,
    small: 36,
    medium: 44, // meets WCAG 2.1 AAA compliance for touch targets.
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#global-size-values) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * May be used for call to action buttons and user input fields.
 *
 ** `remSize.medium` -> 2.75rem
 ** `remSize.small` -> 2.25rem
 ** `remSize.xsmall` -> 1.5rem
 */
const remSize = {
    xsmall: (0, px_to_rem_1.pxToRem)(exports.size.xsmall),
    small: (0, px_to_rem_1.pxToRem)(exports.size.small),
    medium: (0, px_to_rem_1.pxToRem)(exports.size.medium),
};
/*
   We attempt to use these values for icons within Source components.
   They are analogous with component heights defined by the size values
   above. They are based on the size of icons used within the button
   component.
*/
exports.iconSize = {
    xsmall: 20,
    small: 26,
    medium: 30,
};
const remIconSize = {
    xsmall: (0, px_to_rem_1.pxToRem)(exports.iconSize.xsmall),
    small: (0, px_to_rem_1.pxToRem)(exports.iconSize.small),
    medium: (0, px_to_rem_1.pxToRem)(exports.iconSize.medium),
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in px
 *
 ** `height.ctaMedium`: call to action buttons and links
 ** `height.ctaSmall`: secondary calls to action
 ** `height.ctaXsmall`: calls to action where there is very limited space
 ** `height.inputMedium`: text input fields, radio and checkbox labels
 ** `height.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `height.iconMedium`
 ** `height.iconSmall`
 ** `height.iconXsmall`
 */
exports.height = {
    ctaMedium: exports.size.medium,
    ctaSmall: exports.size.small,
    ctaXsmall: exports.size.xsmall,
    inputMedium: exports.size.medium,
    inputXsmall: exports.size.xsmall,
    iconMedium: exports.iconSize.medium,
    iconSmall: exports.iconSize.small,
    iconXsmall: exports.iconSize.xsmall,
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in rem
 *
 ** `remHeight.ctaMedium`: call to action buttons and links
 ** `remHeight.ctaSmall`: secondary calls to action
 ** `remHeight.ctaXsmall`: calls to action where there is very limited space
 ** `remHeight.inputMedium`: text input fields, radio and checkbox labels
 ** `remHeight.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remHeight.iconMedium`
 ** `remHeight.iconSmall`
 ** `remHeight.iconXsmall`
 */
exports.remHeight = {
    ctaMedium: remSize.medium,
    ctaSmall: remSize.small,
    ctaXsmall: remSize.xsmall,
    inputMedium: remSize.medium,
    inputXsmall: remSize.xsmall,
    iconMedium: remIconSize.medium,
    iconSmall: remIconSize.small,
    iconXsmall: remIconSize.xsmall,
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in px
 *
 ** `width.ctaMedium`: medium height call to action buttons and links
 ** `width.ctaSmall`: small height call to action buttons and links
 ** `width.ctaXsmall`: xsmall height call to action buttons and links
 ** `width.inputMedium`: text input fields, radio and checkbox labels
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.inputMedium`
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.iconMedium`
 ** `width.iconSmall`
 ** `width.iconXsmall`
 */
exports.width = {
    ctaMedium: exports.size.medium,
    ctaSmall: exports.size.small,
    ctaXsmall: exports.size.xsmall,
    inputXsmall: exports.size.xsmall,
    iconMedium: exports.iconSize.medium,
    iconSmall: exports.iconSize.small,
    iconXsmall: exports.iconSize.xsmall,
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in rem
 *
 ** `remWidth.ctaMedium`: medium height call to action buttons and links
 ** `remWidth.ctaSmall`: small height call to action buttons and links
 ** `remWidth.ctaXsmall`: xsmall height call to action buttons and links
 ** `remWidth.inputMedium`: text input fields, radio and checkbox labels
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.inputMedium`
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.iconMedium`
 ** `remWidth.iconSmall`
 ** `remWidth.iconXsmall`
 */
exports.remWidth = {
    ctaMedium: remSize.medium,
    ctaSmall: remSize.small,
    ctaXsmall: remSize.xsmall,
    inputXsmall: remSize.xsmall,
    iconMedium: remIconSize.medium,
    iconSmall: remIconSize.small,
    iconXsmall: remIconSize.xsmall,
};
//# sourceMappingURL=size.js.map